==> tsghc-1.1.0.tgz: package/README.md <==
<img src='https://github.com/ljlm0402/tsghc/raw/images/logo.jpg' border='0' alt='logo' />

<a href="https://www.npmjs.com/package/tsghc" target="_blank"><img src="https://img.shields.io/npm/v/tsghc.svg" alt="NPM Version" /></a>
<a href="https://www.npmjs.com/package/tsghc" target="_blank"><img src="https://img.shields.io/npm/l/tsghc.svg" alt="Package License" /></a>
<a href="https://www.npmjs.com/package/tsghc" target="_blank"><img src="https://img.shields.io/github/v/release/ljlm0402/tsghc" alt="Release Version" /></a>
<a href="https://www.npmjs.com/package/tsghc" target="_blank"><img src="https://img.shields.io/npm/dm/tsghc.svg" alt="NPM Downloads" /></a>

<br />

## 🔎 What is it ?

__tsghc__ is a CLI module that quickly clones GitHub Repositories composed of TypeScript.

## 🚀 Quick Start

### Install with the npm global package

```sh
$ npm install -g tsghc
```

### CLI tsghc

```sh
$ tsghc
```

<img src='https://github.com/ljlm0402/tsghc/raw/images/cli.gif' border='0' alt='cli' />

## 🕹 It supports various frameworks.

![](https://img.shields.io/badge/-Angular-DD0031?style=for-the-badge&logo=angular&logoColor=fff)
![](https://img.shields.io/badge/-React-61DAFB?style=for-the-badge&logo=react&logoColor=fff)
![](https://img.shields.io/badge/-Next-000000?style=for-the-badge&logo=next.js&logoColor=fff)
![](https://img.shields.io/badge/-Vue-4FC08D?style=for-the-badge&logo=vue.js&logoColor=fff)
![](https://img.shields.io/badge/-Nuxt-00C58E?style=for-the-badge&logo=nuxt.js&logoColor=fff)
![](https://img.shields.io/badge/-Express-F8F8F5?style=for-the-badge)
![](https://img.shields.io/badge/-Nest-E0234E?style=for-the-badge&logo=nestjs&logoColor=fff)
![](https://img.shields.io/badge/-Fastify-000000?style=for-the-badge&logo=fastify&logoColor=fff)

## 🙏 Please pull request from your repository.

Add it to the template folder file according to your repo's framework. [here](https://github.com/ljlm0402/tsghc/issues/new)

```js
{
    url: '<repo_url>',
    name: '<repo_name>',
    author: '<your_name>',
    description: '<repo_desc>'
}
```

## 📬 Recommended Commit Message

|  When |  Commit Message  |
|:--------|:-----------|
| Add function | feat: ⚡️ Add function |
| Fix bug | fix: 🐞 Fix bug |
| Refactoring | refactor: 🛠 Refactoring |
| Add package | package: 📦 Add package |
| Fix readme | docs: 📚 Fix readme |
| Improvements style | style: 👁 Improvements style |
| New Releases | releases: 🎉 Releases |

## 💳 License

[MIT](LICENSE)

==> tsghc-1.1.2.tgz: package/README.md <==
<img src='https://github.com/ljlm0402/tsghc/raw/images/logo.jpg' border='0' alt='logo' />

<a href="https://www.npmjs.com/package/tsghc" target="_blank"><img src="https://img.shields.io/npm/v/tsghc.svg" alt="NPM Version" /></a>
<a href="https://www.npmjs.com/package/tsghc" target="_blank"><img src="https://img.shields.io/npm/l/tsghc.svg" alt="Package License" /></a>
<a href="https://www.npmjs.com/package/tsghc" target="_blank"><img src="https://img.shields.io/github/v/release/ljlm0402/tsghc" alt="Release Version" /></a>
<a href="https://www.npmjs.com/package/tsghc" target="_blank"><img src="https://img.shields.io/npm/dm/tsghc.svg" alt="NPM Downloads" /></a>

<br />

## 🔎 What is it ?

**tsghc** is a CLI module that quickly clones GitHub Repositories composed of TypeScript.

## 🚀 Quick Start

### Install with the npm global package

```sh
$ npm install -g tsghc
```

### CLI tsghc

```sh
$ tsghc
```

<img src='https://github.com/ljlm0402/tsghc/raw/images/cli.gif' border='0' alt='cli' />

## 🕹 It supports various frameworks.

![](https://img.shields.io/badge/-Angular-DD0031?style=for-the-badge&logo=angular&logoColor=fff)
![](https://img.shields.io/badge/-React-61DAFB?style=for-the-badge&logo=react&logoColor=fff)
![](https://img.shields.io/badge/-Next-000000?style=for-the-badge&logo=next.js&logoColor=fff)
![](https://img.shields.io/badge/-Vue-4FC08D?style=for-the-badge&logo=vue.js&logoColor=fff)
![](https://img.shields.io/badge/-Nuxt-00C58E?style=for-the-badge&logo=nuxt.js&logoColor=fff)
![](https://img.shields.io/badge/-Express-F8F8F5?style=for-the-badge)
![](https://img.shields.io/badge/-Nest-E0234E?style=for-the-badge&logo=nestjs&logoColor=fff)
![](https://img.shields.io/badge/-Fastify-000000?style=for-the-badge&logo=fastify&logoColor=fff)

## 🙏 Please pull request from your repository.

Add it to the template folder file according to your repo's framework. [here](https://github.com/ljlm0402/tsghc/issues/new)

```js
{
    url: '<repo_url>',
    name: '<repo_name>',
    author: '<your_name>',
    description: '<repo_desc>'
}
```

## 📬 Recommended Commit Message

| When               | Commit Message              |
| :----------------- | :-------------------------- |
| Add function       | feat: ⚡️ Add function      |
| Fix bug            | fix: 🐞 Fix bug             |
| Refactoring        | refactor: 🛠 Refactoring     |
| Add package        | package: 📦 Add package     |
| Fix readme         | docs: 📚 Fix readme         |
| Improvements style | style: 👁 Improvements style |
| New Releases       | releases: 🎉 Releases       |

## 💳 License

[MIT](LICENSE)
